miblab
======


.. image:: https://img.shields.io/badge/License-Apache_2.0-blue.svg
  :target: https://opensource.org/licenses/Apache-2.0



Toolbox of the open medical imaging biomarkers lab
--------------------------------------------------

- **Documentation:** https://miblab.org/reference/
- **Source code:** https://github.com/openmiblab/miblab


Installation
------------

Basic version:

.. code-block:: console

    pip install miblab

To include pdf reporting tools:

.. code-block:: console

    pip install miblab[report]

To include data tools

.. code-block:: console

    pip install miblab[data]

License
-------

Released under the `Apache 2.0 <https://opensource.org/licenses/Apache-2.0>`_  
license::

  Copyright (C) 2025 miblab developers

